
/* Generated data (by glib-mkenums) */


/* enumerations from "gnome-app-helper.h" */
    (void) gnome_ui_info_type_get_type ();

    (void) gnome_ui_info_configurable_types_get_type ();

    (void) gnome_ui_pixmap_type_get_type ();


/* enumerations from "gnome-client.h" */
    (void) gnome_interact_style_get_type ();

    (void) gnome_dialog_type_get_type ();

    (void) gnome_save_style_get_type ();

    (void) gnome_restart_style_get_type ();

    (void) gnome_client_state_get_type ();

    (void) gnome_client_flags_get_type ();


/* enumerations from "gnome-dateedit.h" */
    (void) gnome_date_edit_flags_get_type ();


/* enumerations from "gnome-druid-page-edge.h" */
    (void) gnome_edge_position_get_type ();


/* enumerations from "gnome-font-picker.h" */
    (void) gnome_font_picker_mode_get_type ();


/* enumerations from "gnome-icon-list.h" */
    (void) gnome_icon_list_mode_get_type ();


/* enumerations from "gnome-icon-lookup.h" */
    (void) gnome_icon_lookup_flags_get_type ();

    (void) gnome_icon_lookup_result_flags_get_type ();


/* enumerations from "gnome-mdi.h" */
    (void) gnome_mdi_mode_get_type ();


/* enumerations from "gnome-password-dialog.h" */
    (void) gnome_password_dialog_remember_get_type ();


/* enumerations from "gnome-thumbnail.h" */
    (void) gnome_thumbnail_size_get_type ();


/* enumerations from "gnome-types.h" */
    (void) gnome_preferences_type_get_type ();


/* Generated data ends here */

